import os
from typing import Union
from loguru import logger
from UniBotPluginsCaffold.types import PluginInformation

MainPy = """from KobeBryantAPI import Logger

logger = Logger()


def on_enable():
    logger.info(f"{PLUGIN_NAME} on enable.")


def on_disable():
    logger.info(f"{PLUGIN_NAME} on disable.")
"""


class MainPyFileUtil:
    @staticmethod
    def templateFile(pluginInfo: PluginInformation) -> str:
        """
        读取模版文件
        :type pluginInfo: PluginInformation 插件信息
        :return: str
        """
        result = MainPy.split("\n")
        result[3] = f'PLUGIN_NAME = "{pluginInfo.name}"\n'
        result[3] += f'PLUGIN_DESCRIPTION = "{pluginInfo.description}"\n'
        result[3] += f'PLUGIN_VERSION = "{pluginInfo.version}"\n'
        return "\n".join(result)

    @staticmethod
    def create(output: Union[os.PathLike, str], pluginInfo: PluginInformation) -> bool:
        """
        创建 main.py 文件
        :param output: 输出路径
        :param pluginInfo: 插件信息
        :return: bool
        """
        try:
            with open(os.path.join(output, pluginInfo.entry), "w", encoding="utf-8") as f:
                f.write(MainPyFileUtil.templateFile(pluginInfo))
                return True
        except Exception as e:
            logger.error(e)
        return False



import os
from loguru import logger
from UniBotPluginsCaffold.types import PluginInformation, PluginType
from UniBotPluginsCaffold.templates.main import MainPyFileUtil
from UniBotPluginsCaffold.templates.manifestJson import ManifestJsonUtil


class PluginCreator:
    def __init__(self) -> None:
        """
        插件创建器
        """
        self.pluginInfo = PluginInformation
        self.pluginInfo.name = "PluginName"
        self.pluginInfo.entry = self.pluginInfo.name + ".py"
        self.pluginInfo.type = PluginType.python
        self.pluginInfo.version = "v0.0.1"
        self.pluginInfo.description = "A QQ bot plugin."
        self.pluginInfo.preload = []
        self.pluginInfo.dependence = []
        self.pluginInfo.optional_dependence = []

    def create(self, output: os.PathLike = os.getcwd()) -> bool:
        """
        开始创建 / Start creating.
        :param output: 输出路径
        :return: bool
        """
        output = os.path.join(output, self.pluginInfo.name)
        # 创建plugin的目录
        if not os.path.isdir(output):
            logger.info(f"路径：{output}不存在，将自动创建...")
            try:
                os.makedirs(output)
            except OSError as e:
                logger.warning(e)
                return False
            except Exception as e:
                logger.error(e)
                return False

        # 创建 entry
        createEntryResult = MainPyFileUtil.create(output, self.pluginInfo)
        if not createEntryResult:
            logger.error("entry文件创建失败！")
            return False
        # 创建 manifest.json 文件
        createManifestJson = ManifestJsonUtil.createManifestJson(output, self.pluginInfo)
        if not createManifestJson:
            logger.error("manifest.json文件创建失败！")
            return False

        return True



import os

from art import text2art
from loguru import logger
from UniBotPluginsCaffold.create import PluginCreator

# 使用指定字体和装饰生成UniBot PS的ASCII艺术
UniBotPSText2art = text2art("UniBot-PS", space=1)
print(UniBotPSText2art)


def access() -> None:
    print("UniBot-脚手架")
    creator = PluginCreator()

    name = input(f"插件名 ({creator.pluginInfo.name})# ")
    if name:
        creator.pluginInfo.name = name
        creator.pluginInfo.entry = name + ".py"

    entry = input(f"插件入口 ({creator.pluginInfo.entry})# ")
    if entry:
        creator.pluginInfo.entry = entry
    description = input(f"插件描述 ({creator.pluginInfo.description})# ")
    if description:
        creator.pluginInfo.description = description
    version = input(f"版本 ({creator.pluginInfo.version})# ")
    if version:
        creator.pluginInfo.version = version
    pluginDir = os.path.join(os.getcwd(), creator.pluginInfo.name)

    logger.info(f"开始创建: {pluginDir}")
    result = creator.create()

    if not result:
        logger.info(f"插件 {creator.pluginInfo.name} 创建失败！")
    else:
        logger.info(f"插件 {creator.pluginInfo.name} 创建成功！")


from typing import List


class PluginType:
    python: str = "script-python"


class PluginInformation:
    name: str
    entry: str
    type: str
    version: str
    description: str
    preload: List[str]
    passive: bool = False
    dependence: List[str]
    optional_dependence: List[str]


class PluginInformationUtil:
    @staticmethod
    def from_dict(pluginInfo: PluginInformation):
        return {
            "name": pluginInfo.name,
            "entry": pluginInfo.entry,
            "type": pluginInfo.type,
            "version": pluginInfo.version,
            "description": pluginInfo.description,
            "preload": pluginInfo.preload,
            "passive": pluginInfo.passive,
            "dependence": pluginInfo.dependence,
            "optional_dependence": pluginInfo.optional_dependence,
        }




import json
import os.path
from typing import Union
from loguru import logger
from UniBotPluginsCaffold.types import PluginInformation, PluginInformationUtil


class ManifestJsonUtil:
    @staticmethod
    def createManifestJson(output: Union[os.PathLike, str], pluginInfo: PluginInformation) -> bool:
        writeData = PluginInformationUtil.from_dict(pluginInfo)
        try:
            with open(os.path.join(output, 'manifest.json'), 'w', encoding='utf-8') as f:
                f.write(json.dumps(writeData, indent=4))
                return True
        except Exception as e:
            logger.error(e)
        return False



from setuptools import setup, find_packages

setup(
    name='UniBot-plugins-scaffold',
    version='0.0.2',
    author='PYmili',
    author_email='mc2005wj@163.com',
    description='UniBot的插件脚手架',
    long_description=open('README.md', encoding="utf-8").read(),
    long_description_content_type='text/markdown',
    url='https://github.com/PYmili/UniBot-plugins-scaffold',
    packages=find_packages(),
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'Programming Language :: Python :: 3.13',
    ],
    keywords='UniBot plugins',
    install_requires=[
        "art==6.3",
        "colorama==0.4.6",
        "loguru==0.7.2",
        "setuptools==75.6.0",
        "win32-setctime==1.1.0"
    ],  # 这里可以添加项目依赖
    entry_points={
        'console_scripts': [
            'unibot-ps=UniBotPluginsCaffold.command:access',  # 这里的'unibot-ps'是命令行工具的名称，指定了入口函数
        ],
    },
    python_requires='>=3.9',  # 指定支持的Python版本
)
